@@ -8,8 +8,8 @@ import imp
 
 # try to find local settings to retrieve VENV path
 for fpath in ['/etc/nosmsd.conf.py',
-              os.path.expanduser('.nosmsd.conf.py'),
-              os.path.expanduser('nosmsd.conf.py'),
+              os.path.expanduser('~/.nosmsd.conf.py'),
+              os.path.expanduser('~/nosmsd.conf.py'),
               'nosmsd.conf.py']:
     try:
         imp.load_source('settings', fpath)
